@@ -14,5 +14,5 @@ interface FixtureInterface
     /**
      * Load data fixtures with the passed EntityManager
      */
-    public function load(ObjectManager $manager);
+    public function load(ObjectManager $manager): void;
 }
