@@ -9,43 +9,34 @@ use Doctrine\ODM\MongoDB\DocumentManager;
 /**
  * Class responsible for purging databases of data before reloading data fixtures.
  */
-class MongoDBPurger implements PurgerInterface
+final class MongoDBPurger implements MongoDBPurgerInterface
 {
-    /** @var DocumentManager|null */
-    private $dm;
-
     /**
      * Construct new purger instance.
      *
      * @param DocumentManager|null $dm DocumentManager instance used for persistence.
      */
-    public function __construct(?DocumentManager $dm = null)
+    public function __construct(private DocumentManager|null $dm = null)
     {
-        $this->dm = $dm;
     }
 
     /**
      * Set the DocumentManager instance this purger instance should use.
-     *
-     * @return void
      */
-    public function setDocumentManager(DocumentManager $dm)
+    public function setDocumentManager(DocumentManager $dm): void
     {
         $this->dm = $dm;
     }
 
     /**
      * Retrieve the DocumentManager instance this purger instance is using.
-     *
-     * @return DocumentManager
      */
-    public function getObjectManager()
+    public function getObjectManager(): DocumentManager
     {
         return $this->dm;
     }
 
-    /** @inheritDoc */
-    public function purge()
+    public function purge(): void
     {
         $metadatas = $this->dm->getMetadataFactory()->getAllMetadata();
         foreach ($metadatas as $metadata) {
