@@ -12,9 +12,12 @@ use Doctrine\ORM\Tools\SchemaTool;
 use Doctrine\ORM\UnitOfWork;
 use Doctrine\Persistence\Proxy;
 use Doctrine\Tests\Common\DataFixtures\TestEntity\Role;
+use Doctrine\Tests\Common\DataFixtures\TestEntity\User;
 use Doctrine\Tests\Mock\ForwardCompatibleEntityManager;
 use OutOfBoundsException;
 
+use function sprintf;
+
 class ReferenceRepositoryTest extends BaseTestCase
 {
     public function testReferenceEntry(): void
@@ -32,10 +35,12 @@ class ReferenceRepositoryTest extends BaseTestCase
 
         $referenceRepo->addReference('test', $role);
 
-        $references = $referenceRepo->getReferences();
-        $this->assertCount(1, $references);
-        $this->assertArrayHasKey('test', $references);
-        $this->assertInstanceOf(Role::class, $references['test']);
+        $referencesByClass = $referenceRepo->getReferencesByClass();
+        $this->assertCount(1, $referencesByClass);
+        $this->assertArrayHasKey(Role::class, $referencesByClass);
+        $this->assertCount(1, $referencesByClass[Role::class]);
+        $this->assertArrayHasKey('test', $referencesByClass[Role::class]);
+        $this->assertInstanceOf(Role::class, $referencesByClass[Role::class]['test']);
     }
 
     public function testReferenceIdentityPopulation(): void
@@ -57,7 +62,7 @@ class ReferenceRepositoryTest extends BaseTestCase
 
         $referenceRepository->expects($this->once())
             ->method('getReferenceNames')
-            ->will($this->returnValue(['admin-role']));
+            ->willReturn(['admin-role']);
 
         $referenceRepository->expects($this->once())
             ->method('setReferenceIdentity')
@@ -84,13 +89,13 @@ class ReferenceRepositoryTest extends BaseTestCase
 
         $roleFixture->load($em);
         // first test against managed state
-        $ref = $referenceRepository->getReference('admin-role');
+        $ref = $referenceRepository->getReference('admin-role', Role::class);
 
         $this->assertNotInstanceOf(Proxy::class, $ref);
 
         // now test reference reconstruction from identity
         $em->clear();
-        $ref = $referenceRepository->getReference('admin-role');
+        $ref = $referenceRepository->getReference('admin-role', Role::class);
 
         $this->assertInstanceOf(Proxy::class, $ref);
     }
@@ -112,8 +117,8 @@ class ReferenceRepositoryTest extends BaseTestCase
         $em->flush();
         $em->clear();
 
-        $this->assertInstanceOf(Proxy::class, $referenceRepository->getReference('admin'));
-        $this->assertInstanceOf(Proxy::class, $referenceRepository->getReference('duplicate'));
+        $this->assertInstanceOf(Proxy::class, $referenceRepository->getReference('admin', Role::class));
+        $this->assertInstanceOf(Proxy::class, $referenceRepository->getReference('duplicate', Role::class));
     }
 
     public function testUndefinedReference(): void
@@ -121,9 +126,20 @@ class ReferenceRepositoryTest extends BaseTestCase
         $referenceRepository = new ReferenceRepository($this->getMockSqliteEntityManager());
 
         $this->expectException(OutOfBoundsException::class);
-        $this->expectExceptionMessage('Reference to "foo" does not exist');
+        $this->expectExceptionMessage(sprintf('Reference to "foo" for class "%s" does not exist', Role::class));
 
-        $referenceRepository->getReference('foo');
+        $referenceRepository->getReference('foo', Role::class);
+    }
+
+    /** @group legacy */
+    public function testLegacyUndefinedReference(): void
+    {
+        $referenceRepository = new ReferenceRepository($this->getMockSqliteEntityManager());
+
+        $this->expectException(OutOfBoundsException::class);
+        $this->expectExceptionMessage(sprintf('Reference to "foo" for class "%s" does not exist', Role::class));
+
+        $referenceRepository->getReference('foo', Role::class);
     }
 
     public function testThrowsExceptionAddingDuplicatedReference(): void
@@ -134,32 +150,43 @@ class ReferenceRepositoryTest extends BaseTestCase
         $referenceRepository->addReference('duplicated_reference', new Role());
 
         $this->expectException(BadMethodCallException::class);
-        $this->expectExceptionMessage(
-            'Reference to "duplicated_reference" already exists, use method setReference() in order to override it',
-        );
+        $this->expectExceptionMessage(sprintf(
+            'Reference to "duplicated_reference" for class "%s" already exists, use method setReference() in order to override it',
+            Role::class,
+        ));
 
         $referenceRepository->addReference('duplicated_reference', new Role());
     }
 
+    public function testThereIsNoDuplicateWithDifferentClasses(): void
+    {
+        $em                  = $this->getMockSqliteEntityManager();
+        $referenceRepository = new ReferenceRepository($em);
+
+        $referenceRepository->addReference('not_duplicated_reference', new Role());
+        $referenceRepository->addReference('not_duplicated_reference', new User());
+
+        static::assertCount(2, $referenceRepository->getReferencesByClass());
+    }
+
     public function testThrowsExceptionTryingToGetWrongReference(): void
     {
         $referenceRepository = new ReferenceRepository($this->getMockSqliteEntityManager());
 
         $this->expectException(OutOfBoundsException::class);
-        $this->expectExceptionMessage('Reference to "missing_reference" does not exist');
+        $this->expectExceptionMessage(sprintf('Reference to "missing_reference" for class "%s" does not exist', Role::class));
 
-        $referenceRepository->getReference('missing_reference');
+        $referenceRepository->getReference('missing_reference', Role::class);
     }
 
     public function testHasIdentityCheck(): void
     {
-        $role                = new Role();
         $referenceRepository = new ReferenceRepository($this->getMockSqliteEntityManager());
-        $referenceRepository->setReferenceIdentity('entity', $role);
+        $referenceRepository->setReferenceIdentity('entity', 1, Role::class);
 
-        $this->assertTrue($referenceRepository->hasIdentity('entity'));
-        $this->assertFalse($referenceRepository->hasIdentity('invalid_entity'));
-        $this->assertEquals(['entity' => $role], $referenceRepository->getIdentities());
+        $this->assertTrue($referenceRepository->hasIdentity('entity', Role::class));
+        $this->assertFalse($referenceRepository->hasIdentity('invalid_entity', Role::class));
+        $this->assertEquals(['entity' => 1], $referenceRepository->getIdentitiesByClass()[Role::class] ?? []);
     }
 
     public function testSetReferenceHavingIdentifier(): void
@@ -177,7 +204,7 @@ class ReferenceRepositoryTest extends BaseTestCase
         $em->flush();
 
         $referenceRepository->setReference('entity', $role);
-        $identities = $referenceRepository->getIdentities();
+        $identities = $referenceRepository->getIdentitiesByClass()[Role::class] ?? [];
         $this->assertCount(1, $identities);
         $this->assertArrayHasKey('entity', $identities);
     }
@@ -198,6 +225,9 @@ class ReferenceRepositoryTest extends BaseTestCase
             ->method('getIdentifierValues')
             ->with($role)
             ->willReturn($identitiesExpected);
+        $classMetadata->expects($this->once())
+            ->method('getName')
+            ->willReturn(Role::class);
 
         $em = $this->createMock(ForwardCompatibleEntityManager::class);
         $em->method('getUnitOfWork')
@@ -208,7 +238,7 @@ class ReferenceRepositoryTest extends BaseTestCase
 
         $referenceRepository = new ReferenceRepository($em);
         $referenceRepository->setReference('entity', $role);
-        $identities = $referenceRepository->getIdentities();
+        $identities = $referenceRepository->getIdentitiesByClass()[Role::class] ?? [];
 
         $this->assertEquals($identitiesExpected, $identities['entity']);
     }
