@@ -10,62 +10,35 @@ use Doctrine\ORM\Mapping as ORM;
 
 use function md5;
 
-/**
- * @ORM\Entity
- * @ORM\Table(name="user",schema="test_schema")
- */
 #[ORM\Entity]
 #[ORM\Table(name: 'user', schema: 'test_schema')]
 class UserWithSchema
 {
-    /**
-     * @ORM\Column(type="integer")
-     * @ORM\Id
-     */
     #[ORM\Column]
     #[ORM\Id]
-    private ?int $id = null;
+    private int|null $id = null;
 
-    /**
-     * @ORM\Column(length=32)
-     * @ORM\Id
-     */
     #[ORM\Column(length: 32)]
     #[ORM\Id]
-    private ?string $code = null;
+    private string|null $code = null;
 
-    /** @ORM\Column(length=32) */
     #[ORM\Column(length: 32)]
-    private ?string $password = null;
+    private string|null $password = null;
 
-    /** @ORM\Column(length=255) */
     #[ORM\Column(length: 255)]
-    private ?string $email = null;
+    private string|null $email = null;
 
-    /** @ORM\ManyToOne(targetEntity=Role::class, cascade={"persist"}) */
     #[ORM\ManyToOne(cascade: ['persist'])]
-    private ?Role $role = null;
+    private Role|null $role = null;
 
-    /**
-     * @ORM\ManyToMany(targetEntity=UserWithSchema::class, inversedBy="authors")
-     * @ORM\JoinTable(name="author_reader", schema="readers",
-     *      joinColumns={@ORM\JoinColumn(name="author_id", referencedColumnName="id")},
-     *      inverseJoinColumns={@ORM\JoinColumn(name="reader_id", referencedColumnName="id")}
-     * )
-     *
-     * @var Collection<int, self>
-     */
+    /** @var Collection<int, self> */
     #[ORM\ManyToMany(targetEntity: self::class, inversedBy: 'authors')]
     #[ORM\JoinTable(name: 'author_reader', schema: 'readers')]
     #[ORM\JoinColumn(name: 'author_id', referencedColumnName: 'id')]
     #[ORM\InverseJoinColumn(name: 'reader_id', referencedColumnName: 'id')]
     private Collection $readers;
 
-    /**
-     * @ORM\ManyToMany(targetEntity=UserWithSchema::class, mappedBy="readers")
-     *
-     * @var Collection<int, self>
-     */
+    /** @var Collection<int, self> */
     #[ORM\ManyToMany(targetEntity: self::class, mappedBy: 'readers')]
     private Collection $authors;
 
@@ -80,7 +53,7 @@ class UserWithSchema
         $this->id = $id;
     }
 
-    public function getId(): ?int
+    public function getId(): int|null
     {
         return $this->id;
     }
@@ -90,7 +63,7 @@ class UserWithSchema
         $this->code = $code;
     }
 
-    public function getCode(): ?string
+    public function getCode(): string|null
     {
         return $this->code;
     }
@@ -100,7 +73,7 @@ class UserWithSchema
         $this->password = md5($password);
     }
 
-    public function getPassword(): ?string
+    public function getPassword(): string|null
     {
         return $this->password;
     }
@@ -110,7 +83,7 @@ class UserWithSchema
         $this->email = $email;
     }
 
-    public function getEmail(): ?string
+    public function getEmail(): string|null
     {
         return $this->email;
     }
@@ -120,7 +93,7 @@ class UserWithSchema
         $this->role = $role;
     }
 
-    public function getRole(): ?Role
+    public function getRole(): Role|null
     {
         return $this->role;
     }
